from sqlalchemy import Column, Integer, String, ForeignKey, PrimaryKeyConstraint

from arepo.models import Base


class LineModel(Base):
    __tablename__ = "line"

    id = Column('id', String, primary_key=True)
    number = Column('number', Integer, nullable=False)
    content = Column('content', String, nullable=False)
    commit_file_id = Column(String, ForeignKey('commit_file.id'))


class LabelModel(Base):
    __tablename__ = "label"

    id = Column('id', Integer, primary_key=True)
    name = Column('name', String, nullable=False)


class LineLabelModel(Base):
    __tablename__ = "line_label"
    __table_args__ = (
        PrimaryKeyConstraint('line_id', 'label_id'),
    )

    line_id = Column('line_id', String, ForeignKey('line.id'))
    label_id = Column('label_id', Integer, ForeignKey('label.id'))


class FunctionModel(Base):
    __tablename__ = "function"

    id = Column('id', String, primary_key=True)
    name = Column('name', String, nullable=False)
    commit_file_id = Column(String, ForeignKey('commit_file.id'))
    start_line = Column('start_line', Integer, nullable=False)
    start_col = Column('start_col', Integer, nullable=False)
    end_line = Column('end_line', Integer, nullable=False)
    end_col = Column('end_col', Integer, nullable=False)
    size = Column('size', Integer, nullable=False)




from arepo.db import DatabaseConnection


def main():
    db_uri = "sqlite:///:memory:"
    print('Initializing the database.')
    engine = DatabaseConnection.init(db_uri)
    print('Database initialized.')
    print('engine:', engine)
    print('Getting database connection.')
    db = DatabaseConnection(db_uri, engine)
    print('Getting session.')
    session = db.get_session(scoped=True)
    from arepo.models.common.vulnerability import TagModel
    print('Querying tags.')
    tags = session.query(TagModel).all()

    for tag in tags:
        print(tag.id, tag.name)

    session.close()
    print('Session closed.')
    print('Done.')
